@@ -9,16 +9,14 @@ import flask
 from opentelemetry.instrumentation.flask import (
     _InstrumentedFlask,
     FlaskInstrumentor,
-    get_default_span_name,
-    _teardown_request,
     _ENVIRON_SPAN_KEY,
 )
 from werkzeug.exceptions import Forbidden
 
 from hypertrace.agent import constants  # pylint: disable=R0801
-from hypertrace.agent.filter.registry import Registry
+from hypertrace.agent.filter.registry import Registry, TYPE_HTTP
 from hypertrace.agent.instrumentation import BaseInstrumentorWrapper
-from hypertrace.agent.init import AgentInit
+
 from hypertrace.agent.config import AgentConfig
 
 # Initialize logger
@@ -50,7 +48,8 @@ def _hypertrace_before_request(flask_wrapper):
             block_result = Registry().apply_filters(span,
                                                     flask.request.url,
                                                     flask.request.headers,
-                                                    flask.request.data)
+                                                    flask.request.data,
+                                                    TYPE_HTTP)
             if block_result:
                 logger.debug('should block evaluated to true, aborting with 403')
                 flask.abort(403)
@@ -152,13 +151,13 @@ class FlaskInstrumentorWrapper(FlaskInstrumentor, BaseInstrumentorWrapper):
 
     # Initialize instrumentation wrapper
     @staticmethod
-    def instrument_app(app, request_hook=None, response_hook=None, tracer_provider=None):
+    def instrument_app(app, request_hook=None, response_hook=None, tracer_provider=None, excluded_urls=None):  # pylint:disable=W0221,W0613
         '''Initialize instrumentation'''
         logger.debug('Entering FlaskInstrumentorWrapper.instument_app().')
         try:
 
             # Call parent class's initialization
-            FlaskInstrumentor.instrument_app(app, request_hook, response_hook, None)
+            FlaskInstrumentor.instrument_app(app, request_hook, response_hook)
 
         except Exception as err:  # pylint: disable=W0703
             logger.error("""An error occurred initializing flask otel
